@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+# vim:fenc=utf-8
 #
 # Copyright 2013 Xavier Bruhiere
 #
@@ -12,17 +14,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# -*- coding: utf-8 -*-
-# vim:fenc=utf-8
 
 
 import abc
 
 from zipline.algorithm import TradingAlgorithm
 from zipline.sources import DataFrameSource
-#from zipline.protocol import Event
-#import zipline.protocol
 
 
 class TradingFactory(TradingAlgorithm):
@@ -37,11 +34,12 @@ class TradingFactory(TradingAlgorithm):
 
     __metaclass__ = abc.ABCMeta
 
-    is_live = False
     #TODO Use another zipline mechanism
     day = 0
     sids = []
     middlewares = []
+    orderbook = {}
+    auto = False
 
     def __init__(self, *args, **kwargs):
         self.data_generator = DataFrameSource
@@ -50,6 +48,7 @@ class TradingFactory(TradingAlgorithm):
     def use(self, func, when='whenever'):
         ''' Append a middleware to the algorithm '''
         #NOTE A middleware Object ?
+        print('registering middleware {}'.format(func.__name__))
         self.middlewares.append({
             'call': func,
             'name': func.__name__,
@@ -57,23 +56,9 @@ class TradingFactory(TradingAlgorithm):
             'when': when})
 
     def trade(self, source, sim_params=None):
-        '''
-        if self.is_live:
-            benchmark_return_source = [
-                Event({'dt': dt,
-                       'returns': 0.0,
-                       'type': zipline.protocol.DATASOURCE_TYPE.BENCHMARK,
-                       'source_id': 'benchmarks'})
-                for dt in source['index']
-                if dt.date() >= sim_params.period_start.date()
-                and dt.date() <= sim_params.period_end.date()]
-          '''
-
         if isinstance(source, dict):
             source = self.data_generator(source)
 
-        #return self.run(source, sim_params, benchmark_return_source)
-        # 0.5.9 compatibility
         return self.run(source, sim_params)
 
     #TODO How can I use several sources ?
@@ -96,8 +81,9 @@ class TradingFactory(TradingAlgorithm):
         place to factorize algorithms and then call event() '''
         self.day += 1
         signals = {}
+        self.orderbook = {}
 
-        if self.initialized:
+        if self.initialized and self.manager:
             self.manager.update(
                 self.portfolio,
                 self.datetime,
@@ -110,19 +96,20 @@ class TradingFactory(TradingAlgorithm):
 
         signals = self.event(data)
 
+        if signals and self.manager:
+            self.orderbook = self.manager.trade_signals_handler(signals)
+            if self.auto:
+                self.process_orders(self.orderbook)
+
         self._call_middlewares()
 
-        if signals:
-            order_book = self.manager.trade_signals_handler(signals)
-            self.process_orders(order_book)
-
-    def process_orders(self, order_book):
+    def process_orders(self, orderbook):
         ''' Default and costant orders processor. Overwrite it for more
         sophistiated strategies '''
-        for stock in order_book:
-            self.order(stock, order_book[stock])
+        for stock in orderbook:
+            self.order(stock, orderbook[stock])
             self.logger.debug('{}: Ordered {} {} stocks'.format(
-                self.datetime, stock, order_book[stock]))
+                self.datetime, stock, orderbook[stock]))
 
     def _call_one_middleware(self, middleware):
         ''' Evaluate arguments and execute the middleware function '''
@@ -131,8 +118,8 @@ class TradingFactory(TradingAlgorithm):
             if hasattr(self, arg):
                 # same as eval() but safer for arbitrary code execution
                 args[arg] = reduce(getattr, arg.split('.'), self)
-        self.logger.info('calling middleware event {}'
-                         .format(middleware['name']))
+        self.logger.debug('calling middleware event {}'
+                          .format(middleware['name']))
         middleware['call'](**args)
 
     def _check_condition(self, when):
